@@ -11,11 +11,15 @@ n <- 100
 x <- as.matrix(matrix(rnorm(95*n),n,95) %*% chol(Sigma))
 y <- 10 + x %*% beta + rnorm(n,0,10)
 
+## Structured Elastic.net
+p <- ncol(x)
+C <- bandSparse(p,k=0:1,diagonals=list(rep(1,p),rep(-1,p-1)))
+
 ## This gives a great advantage to the elastic-net
 ## for support recovery
 beta.lasso <- slot(crossval(x,y,lambda2=0) , "beta.min")
 beta.enet  <- slot(crossval(x,y,lambda2=10), "beta.min")
-beta.struc <- slot(crossval(x,y,lambda2=10,struct=solve(Sigma)), "beta.min")
+beta.struc <- slot(crossval(x,y,lambda2=10,struct=t(C) %*% C), "beta.min")
 
 cat("\nFalse positives for the Lasso:", sum(sign(beta) != sign(beta.lasso)))
 cat("\nFalse positives for the Elastic-net:", sum(sign(beta) != sign(beta.enet)))
